@@ -1,6 +1,6 @@
 """
 
-Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2016 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
 Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -32,10 +32,11 @@ Usage: see ../README.windows
 FULLAUTHOR = "Wolfgang Rohdewald <wolfgang@rohdewald.de>"
 LICENSE = 'GNU General Public License v2'
 URL = "http://www.kde.org/applications/games/kajongg/"
-VERSION = "4.13.0"
+VERSION = "17.04"
 # ==========================
 
 import os
+import sys
 import re
 import msilib
 from shutil import rmtree
@@ -56,7 +57,7 @@ includes = [
     "pkg_resources"]
 packages = []
 namespace_packages = ["zope"]
-include_files = ('share',)
+include_files = ('share', os.path.join(sys.base_prefix, 'DLLs', 'sqlite3.dll'))
 
 excludes = ['tcl', 'tk', 'ttk', 'tkinter', 'Tkconstants', 'Tkinter']
 # strangely, excluding modules does not get rid of warnings about missing
@@ -64,11 +65,11 @@ excludes = ['tcl', 'tk', 'ttk', 'tkinter', 'Tkconstants', 'Tkinter']
 
 build_exe_options = {
     "packages": packages, "excludes": excludes, "includes": includes,
-    "include_files": include_files, 'icon': 'kajongg.ico',
-    "namespace_packages": namespace_packages, "append_script_to_exe": True, 'silent': False}
+    "include_files": include_files,
+    "namespace_packages": namespace_packages, 'silent': False}
 
 kajExe = Executable('kajongg.py', icon='kajongg.ico', base='Win32GUI',
-                    shortcutName='Kajongg', shortcutDir='ProgramMenuFolder')
+                    shortcutName='kajongg', shortcutDir='ProgramMenuFolder')
 kajServer = Executable('kajonggserver.py', icon='kajongg.ico')
 executables = [kajExe, kajServer]
 
@@ -103,7 +104,7 @@ class bdist_msi(windist.bdist_msi):
 
 setup(
     cmdclass={'bdist_msi': bdist_msi},  # define custom build class
-    name='Kajongg',
+    name='kajongg',
     version=VERSION,
     description='The classical game of Mah Jongg',
     long_description="This is the classical Mah Jongg for four players. "
@@ -112,7 +113,7 @@ setup(
     author=AUTHOR,
     author_email=EMAIL,
     url=URL,
-    download_url='http://www.kde-apps.org/content/download.php?content=103206&id=1',
+    download_url='https://www.linux-apps.com/p/1109453/',
     options={"build_exe": build_exe_options},
     executables=executables,
     license=LICENSE)
